"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.roleRepository = exports.RoleRepository = void 0;
const utils_1 = require("../../methods/utils");
const model_1 = require("../model");
const scopeRepository_1 = require("./scopeRepository");
const service_common_1 = require("@crosslab/service-common");
class RoleRepository extends service_common_1.AbstractRepository {
    constructor() {
        super('Role');
    }
    initialize(AppDataSource) {
        this.repository = AppDataSource.getRepository(model_1.RoleModel);
    }
    async create(data) {
        const model = await super.create(data);
        model.users = [];
        return model;
    }
    async write(model, data) {
        if (data.name) {
            model.name = data.name;
        }
        if (data.scopes) {
            model.scopes = await Promise.all(data.scopes.map(async (scope) => {
                return await scopeRepository_1.scopeRepository.findOneOrFail({
                    where: {
                        name: scope,
                    },
                });
            }));
        }
    }
    async format(model) {
        return {
            url: (0, utils_1.roleUrlFromId)(model.uuid),
            id: model.uuid,
            name: model.name,
            scopes: await Promise.all(model.scopes.map(scopeRepository_1.scopeRepository.format)),
        };
    }
    getDefaultFindOptionsRelations() {
        return {
            users: true,
            scopes: true,
        };
    }
    addUserModelToRoleModel(roleModel, userModel) {
        if (!roleModel.users.find((user) => user.uuid === userModel.uuid)) {
            roleModel.users.push(userModel);
        }
    }
    removeUserModelFromRoleModel(roleModel, userModel) {
        let index = roleModel.users.findIndex((user) => user.uuid === userModel.uuid);
        while (index !== -1) {
            roleModel.users.splice(index, 1);
            index = roleModel.users.findIndex((user) => user.uuid === userModel.uuid);
        }
    }
}
exports.RoleRepository = RoleRepository;
exports.roleRepository = new RoleRepository();
//# sourceMappingURL=roleRepository.js.map