"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tokenRepository = exports.TokenRepository = void 0;
const model_1 = require("../model");
const roleRepository_1 = require("./roleRepository");
const scopeRepository_1 = require("./scopeRepository");
const userRepository_1 = require("./userRepository");
const service_common_1 = require("@crosslab/service-common");
class TokenRepository extends service_common_1.AbstractRepository {
    constructor() {
        super('Token');
    }
    initialize(AppDataSource) {
        this.repository = AppDataSource.getRepository(model_1.TokenModel);
    }
    async write(model, data) {
        if (data.device)
            model.device = data.device;
        if (data.expiresOn)
            model.expiresOn = data.expiresOn;
        if (data.scopes)
            model.scopes = await Promise.all(data.scopes.map(async (scope) => {
                return await scopeRepository_1.scopeRepository.findOneOrFail({
                    where: {
                        name: scope,
                    },
                });
            }));
        if (data.roles)
            model.roles = await Promise.all(data.roles.map(async (role) => {
                return await roleRepository_1.roleRepository.findOneOrFail({
                    where: {
                        name: role,
                    },
                });
            }));
        if (data.user)
            model.user = await userRepository_1.userRepository.findOneOrFail({
                where: {
                    username: data.user,
                },
            });
    }
    async format(_model) {
        return undefined;
    }
    addScopeModelToTokenModel(tokenModel, scopeModel) {
        if (!tokenModel.scopes.find((scope) => scope.name === scopeModel.name)) {
            tokenModel.scopes.push(scopeModel);
        }
    }
    addRoleModelToTokenModel(tokenModel, roleModel) {
        if (!tokenModel.roles.find((role) => role.name === roleModel.name)) {
            tokenModel.roles.push(roleModel);
        }
    }
    getDefaultFindOptionsRelations() {
        return {
            scopes: true,
            roles: {
                scopes: true,
            },
            user: true,
        };
    }
}
exports.TokenRepository = TokenRepository;
exports.tokenRepository = new TokenRepository();
//# sourceMappingURL=tokenRepository.js.map