"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postDeviceAuthenticationToken = void 0;
const tokenRepository_1 = require("../database/repositories/tokenRepository");
const userRepository_1 = require("../database/repositories/userRepository");
const api_1 = require("../methods/api");
const errors_1 = require("../types/errors");
/**
 * This function implements the functionality for handling POST requests on /device_authentication_token endpoint.
 * @param parameters The parameters of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Could not find user.
 */
const postDeviceAuthenticationToken = async (parameters, user) => {
    console.log(`postDeviceAuthenticationToken called`);
    const userModel = await userRepository_1.userRepository.findOneOrFail({
        where: {
            username: user.JWT.username,
        },
    });
    const device = await (0, api_1.getDevice)(parameters.device_url);
    if (device.owner !== user.JWT.url &&
        !user.JWT.scopes.includes("device_token") &&
        !user.JWT.scopes.includes("device_token:create")) {
        throw new errors_1.OwnershipError();
    }
    const tokenModel = await tokenRepository_1.tokenRepository.create({
        user: userModel.username,
        scopes: [],
        device: device.url,
        roles: ['device'],
    });
    userModel.tokens.push(tokenModel);
    await userRepository_1.userRepository.save(userModel);
    console.log(`postDeviceAuthenticationToken succeeded`);
    return {
        status: 201,
        body: tokenModel.token,
    };
};
exports.postDeviceAuthenticationToken = postDeviceAuthenticationToken;
//# sourceMappingURL=deviceAuthenticationToken.js.map