"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchIdentity = exports.getIdentity = void 0;
const userRepository_1 = require("../database/repositories/userRepository");
/**
 * This function implements the functionality for handling GET requests on /identity endpoint.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if user is not found in database.
 */
const getIdentity = async (user) => {
    console.log(`getIdentity called`);
    const userModel = await userRepository_1.userRepository.findOneOrFail({
        where: {
            username: user.JWT?.username,
        },
    });
    console.log(`getIdentity succeeded`);
    return {
        status: 200,
        body: await userRepository_1.userRepository.format(userModel),
    };
};
exports.getIdentity = getIdentity;
/**
 * This function implements the functionality for handling PATCH requests on /identity endpoint.
 * @param body The body of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if user is not found in database.
 * @throws {InvalidValueError} Can throw errors from {@link writeUserModel}.
 */
const patchIdentity = async (body, user) => {
    console.log(`patchIdentity called`);
    const userModel = await userRepository_1.userRepository.findOneOrFail({
        where: {
            username: user.JWT?.username,
        },
    });
    await userRepository_1.userRepository.write(userModel, body ?? {});
    await userRepository_1.userRepository.save(userModel);
    console.log(`patchIdentity succeeded`);
    return {
        status: 200,
        body: await userRepository_1.userRepository.format(userModel),
    };
};
exports.patchIdentity = patchIdentity;
//# sourceMappingURL=identity.js.map