"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postLogout = void 0;
const tokenRepository_1 = require("../database/repositories/tokenRepository");
const userRepository_1 = require("../database/repositories/userRepository");
/**
 * This function implements the functionality for handling POST requests on /logout endpoint.
 * @param body The body of the request.
 * @param user The user submitting the request.
 * @throws {MissingEntityError} Thrown if user or token is not found in the database.
 */
const postLogout = async (body, user) => {
    console.log(`postLogout called for ${user.JWT?.username}`);
    const userModel = await userRepository_1.userRepository.findOneOrFail({
        where: {
            username: user.JWT?.username,
        },
    });
    const tokenModel = userModel.tokens.find((tm) => tm.token === body.token);
    if (tokenModel)
        await tokenRepository_1.tokenRepository.remove(tokenModel);
    console.log(`postLogout succeeded`);
    return {
        status: 204,
    };
};
exports.postLogout = postLogout;
//# sourceMappingURL=logout.js.map