"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postRegister = void 0;
const roleRepository_1 = require("../database/repositories/roleRepository");
const userRepository_1 = require("../database/repositories/userRepository");
const errors_1 = require("../types/errors");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function implements the functionality for handling POST requests on /register endpoint.
 * @param body The body of the request.
 * @throws {AuthenticationError} Thrown if the authentication was unsuccessful.
 */
const postRegister = async (body) => {
    console.log(`postRegister called`);
    const existingUser = await userRepository_1.userRepository.findOne({
        where: {
            username: `local:${body.username}`,
        },
    });
    if (existingUser)
        throw new errors_1.RegistrationError('User with the same username already exists', 400);
    const newUser = await userRepository_1.userRepository.create({
        username: `local:${body.username}`,
        password: body.password,
    });
    try {
        const roleModelUser = await roleRepository_1.roleRepository.findOneOrFail({
            where: {
                name: 'user',
            },
        });
        userRepository_1.userRepository.addRoleModelToUserModel(newUser, roleModelUser);
        await userRepository_1.userRepository.save(newUser);
    }
    catch (error) {
        if (error instanceof service_common_1.MissingEntityError)
            throw new service_common_1.InconsistentDatabaseError("Role 'user' is missing in database", 500);
        else
            throw new errors_1.RegistrationError('User could not be registered', 500);
    }
    console.log(`postRegister succeeded`);
    return {
        status: 201,
    };
};
exports.postRegister = postRegister;
//# sourceMappingURL=register.js.map